/* Lepton EDA library
 * Copyright (C) 1998-2010 Ales Hvezda
 * Copyright (C) 1998-2015 gEDA Contributors
 * Copyright (C) 2021-2022 Lepton EDA Contributors
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
/*! \file point.h
 */

typedef struct st_point LeptonPoint;

struct st_point
{
  gint x;
  gint y;
};

G_BEGIN_DECLS

void
lepton_point_rotate (int x,
                     int y,
                     int angle,
                     int *newx,
                     int *newy);
void
lepton_point_rotate_90 (int x,
                        int y,
                        int angle,
                        int *newx,
                        int *newy);

G_END_DECLS
